diff --git FL/Fl_File_Chooser.H FL/Fl_File_Chooser.H
index 4ce459ebf..5d7c1eb80 100644
--- FL/Fl_File_Chooser.H
+++ FL/Fl_File_Chooser.H
@@ -87,6 +87,7 @@ private:
   Fl_File_Browser *fileList;
   inline void cb_fileList_i(Fl_File_Browser*, void*);
   static void cb_fileList(Fl_File_Browser*, void*);
+  Fl_Box *errorBox;
   Fl_Box *previewBox;
 public:
   Fl_Check_Button *previewButton;
diff --git src/Fl_File_Chooser.cxx src/Fl_File_Chooser.cxx
index 4b0d27f82..bcd2e588c 100644
--- src/Fl_File_Chooser.cxx
+++ src/Fl_File_Chooser.cxx
@@ -202,6 +202,12 @@ Fl_File_Chooser::Fl_File_Chooser(const char *d, const char *p, int t, const char
         fileList->callback((Fl_Callback*)cb_fileList);
         fileList->window()->hotspot(fileList);
       } // Fl_File_Browser* fileList
+      { errorBox = new Fl_Box(10, 45, 295, 225, "dynamic error display");
+        errorBox->labelsize(18);
+        errorBox->labelcolor((Fl_Color)1);
+        errorBox->align(Fl_Align(FL_ALIGN_TOP_LEFT|FL_ALIGN_INSIDE));
+        errorBox->hide();
+      } // Fl_Box* errorBox
       { previewBox = new Fl_Box(305, 45, 175, 225, "?");
         previewBox->box(FL_DOWN_BOX);
         previewBox->labelsize(100);
diff --git src/Fl_File_Chooser.fl src/Fl_File_Chooser.fl
index fca0a32f3..28ffb5360 100644
--- src/Fl_File_Chooser.fl
+++ src/Fl_File_Chooser.fl
@@ -68,7 +68,8 @@ class FL_EXPORT Fl_File_Chooser {open
   }
   decl {void update_preview();} {private local
   }
-  Function {Fl_File_Chooser(const char *d, const char *p, int t, const char *title)} {} {
+  Function {Fl_File_Chooser(const char *d, const char *p, int t, const char *title)} {open
+  } {
     code {if (!prefs_) {
   prefs_ = new Fl_Preferences(Fl_Preferences::USER, "fltk.org", "filechooser");
 }} {}
@@ -79,7 +80,7 @@ class FL_EXPORT Fl_File_Chooser {open
 fileList->deselect();
 Fl::remove_timeout((Fl_Timeout_Handler)previewCB, this);
 window->hide();} open
-      private xywh {507 327 490 380} type Double hide resizable
+      private xywh {638 588 490 380} type Double hide resizable
       code0 {if (title) window->label(title);}
       code1 {\#include <stdio.h>}
       code2 {\#include <stdlib.h>}
@@ -108,7 +109,7 @@ window->hide();} open
         }
       }
       Fl_Tile {} {
-        callback {update_preview();}
+        callback {update_preview();} open
         private xywh {10 45 470 225} resizable
       } {
         Fl_File_Browser fileList {
@@ -116,6 +117,10 @@ window->hide();} open
           private xywh {10 45 295 225} type Hold hotspot
           code0 {\#include <FL/Fl_File_Browser.H>}
         }
+        Fl_Box errorBox {
+          label {dynamic error display} selected
+          private xywh {10 45 295 225} labelsize 18 labelcolor 1 align 21 hide
+        }
         Fl_Box previewBox {
           label {?}
           private xywh {305 45 175 225} box DOWN_BOX labelsize 100 align 80
@@ -351,7 +356,7 @@ okButton->parent()->init_sizes();} {}
   } {
     code {fileList->textfont(f);} {}
   }
-  Function {textfont()} {selected return_type Fl_Font
+  Function {textfont()} {return_type Fl_Font
   } {
     code {return (fileList->textfont());} {}
   }
diff --git src/Fl_File_Chooser2.cxx src/Fl_File_Chooser2.cxx
index 80d842bcf..51d8f0e36 100644
--- src/Fl_File_Chooser2.cxx
+++ src/Fl_File_Chooser2.cxx
@@ -1099,7 +1099,14 @@ Fl_File_Chooser::rescan()
     okButton->deactivate();
 
   // Build the file list...
-  fileList->load(directory_, sort);
+  int nfiles = fileList->load(directory_, sort);
+  if (nfiles <= 0) {
+    // fprintf(stderr, "No files found\n");
+    errorBox->label("No files found ...");
+    errorBox->show();
+  } else {
+    errorBox->hide();
+  }
   if (Fl::system_driver()->dot_file_hidden() && !showHiddenButton->value()) remove_hidden_files();
   // Update the preview box...
   update_preview();
